# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import div_rotation_transformation, div_translation_transformation


DivTransformation = Union[
    div_rotation_transformation.DivRotationTransformation,
    div_translation_transformation.DivTranslationTransformation,
]
